@@ -62,7 +62,14 @@
 #' @param priors_bias_null list of prior weight functions for the \code{omega} parameter
 #' that will be treated as belonging to the null hypothesis. Defaults no publication
 #' bias adjustment, \code{prior_none()}.
-#' @param chains a number of chains of the MCMC algorithm
+#' @param priors_rho list of prior distributions for the variance allocation (\code{rho})
+#' parameter that will be treated as belonging to the alternative hypothesis. This setting allows
+#' users to fit a three-level meta-analysis when \code{study_ids} are supplied. Note that this is
+#' an experimental feature and see News for more details. Defaults to a beta distribution
+#' \code{prior(distribution = "beta", parameters = list(alpha = 1, beta = 1))}.
+#' @param priors_rho_null list of prior distributions for the variance allocation (\code{rho})
+#' parameter that will be treated as belonging to the null hypothesis. Defaults to \code{NULL}.
+#' @param chains a number of chains of the MCMC algorithm.
 #' @param sample a number of sampling iterations of the MCMC algorithm.
 #' Defaults to \code{5000}.
 #' @param burnin a number of burnin iterations of the MCMC algorithm.
@@ -176,7 +183,7 @@
 RoBMA <- function(
   # data specification
   d = NULL, r = NULL, logOR = NULL, z = NULL, y = NULL,
-  se = NULL, v = NULL, n = NULL, lCI = NULL, uCI = NULL, t = NULL, study_names = NULL,
+  se = NULL, v = NULL, n = NULL, lCI = NULL, uCI = NULL, t = NULL, study_names = NULL, study_ids = NULL,
   data = NULL,
   transformation   = if(is.null(y)) "fishers_z" else "none",
   prior_scale      = if(is.null(y)) "cohens_d"  else "none",
@@ -199,6 +206,8 @@ RoBMA <- function(
   priors_effect_null         = prior(distribution = "point", parameters = list(location = 0)),
   priors_heterogeneity_null  = prior(distribution = "point", parameters = list(location = 0)),
   priors_bias_null           = prior_none(),
+  priors_rho                 = prior("beta", parameters = list(alpha = 1, beta = 1)),
+  priors_rho_null            = NULL,
 
   # MCMC fitting settings
   chains = 3, sample = 5000, burnin = 2000, adapt = 500, thin = 1, parallel = FALSE,
@@ -216,9 +225,12 @@ RoBMA <- function(
   if("data.RoBMA" %in% class(data)){
     object$data <- data
   }else{
-    object$data <- combine_data(d = d, r = r, z = z, logOR = logOR, t = t, y = y, se = se, v = v, n = n, lCI = lCI, uCI = uCI, study_names = study_names, data = data, transformation = transformation)
+    object$data <- combine_data(d = d, r = r, z = z, logOR = logOR, t = t, y = y, se = se, v = v, n = n, lCI = lCI, uCI = uCI, study_names = study_names, study_ids = study_ids, data = data, transformation = transformation)
   }
 
+  if(!attr(object$data, "all_independent")){
+    .multivariate_warning()
+  }
 
   ### check MCMC settings
   object$fit_control        <- BayesTools::JAGS_check_and_list_fit_settings(chains = chains, adapt = adapt, burnin = burnin, sample = sample, thin = thin, autofit = autofit, parallel = parallel, cores = chains, silent = silent, seed = seed)
@@ -241,8 +253,8 @@ RoBMA <- function(
 
 
   ### prepare and check the settings
-  object$priors   <- .check_and_list_priors(object$add_info[["model_type"]], priors_effect_null, priors_effect, priors_heterogeneity_null, priors_heterogeneity, priors_bias_null, priors_bias, object$add_info[["prior_scale"]])
-  object$models   <- .make_models(object[["priors"]])
+  object$priors   <- .check_and_list_priors(object$add_info[["model_type"]], priors_effect_null, priors_effect, priors_heterogeneity_null, priors_heterogeneity, priors_bias_null, priors_bias, priors_rho_null, priors_rho, object$add_info[["prior_scale"]])
+  object$models   <- .make_models(object[["priors"]], !attr(object$data, "all_independent"))
   object$add_info$warnings <- c(object$add_info[["warnings"]], .check_effect_direction(object))
 
 
@@ -264,7 +276,7 @@ RoBMA <- function(
 
     fitting_order <- .fitting_priority(object[["models"]])
 
-    cl <- parallel::makePSOCKcluster(floor(parallel::detectCores() - 1 / object$fit_control[["chains"]]))
+    cl <- parallel::makePSOCKcluster(floor(RoBMA.get_option("max_cores") / object$fit_control[["chains"]]))
     parallel::clusterEvalQ(cl, {library("RoBMA")})
     parallel::clusterExport(cl, "object", envir = environment())
     object$models <- parallel::parLapplyLB(cl, fitting_order, .fit_RoBMA_model, object = object)[order(fitting_order)]
@@ -344,6 +356,13 @@ RoBMA <- function(
 #' @param prior_bias_null prior distribution for the publication bias adjustment
 #' component that will be treated as belonging to the null hypothesis.
 #' Defaults to \code{NULL}.
+#' @param prior_rho prior distributions for the variance allocation (\code{rho})
+#' parameter that will be treated as belonging to the alternative hypothesis. This setting allows
+#' users to fit a three-level meta-analysis when \code{study_ids} are supplied. Note that this is
+#' an experimental feature and see News for more details. Defaults to a beta distribution
+#' \code{prior(distribution = "beta", parameters = list(alpha = 1, beta = 1))}.
+#' @param prior_rho_null prior distributions for the variance allocation (\code{rho})
+#' parameter that will be treated as belonging to the null hypothesis. Defaults to \code{NULL}.
 #' @param prior_weights either a single value specifying prior model weight
 #' of a newly specified model using priors argument, or a vector of the
 #' same length as already fitted models to update their prior weights.
@@ -382,8 +401,8 @@ RoBMA <- function(
 #' @seealso [RoBMA()], [summary.RoBMA()], [prior()], [check_setup()]
 #' @export
 update.RoBMA <- function(object, refit_failed = TRUE,
-                         prior_effect = NULL,      prior_heterogeneity = NULL,      prior_bias = NULL, prior_weights = NULL,
-                         prior_effect_null = NULL, prior_heterogeneity_null = NULL, prior_bias_null = NULL,
+                         prior_effect = NULL,      prior_heterogeneity = NULL,      prior_bias = NULL,      prior_rho = NULL, prior_weights = NULL,
+                         prior_effect_null = NULL, prior_heterogeneity_null = NULL, prior_bias_null = NULL, prior_rho_null = NULL,
                          study_names = NULL,
                          chains = NULL, adapt = NULL, burnin = NULL, sample = NULL, thin = NULL, autofit = NULL, parallel = NULL,
                          autofit_control = NULL, convergence_checks = NULL,
@@ -409,9 +428,9 @@ update.RoBMA <- function(object, refit_failed = TRUE,
      (!is.null(prior_bias)           | !is.null(prior_bias_null))){
 
     what_to_do <- "fit_new_model"
-    new_priors <- .check_and_list_priors(NULL, prior_effect_null, prior_effect, prior_heterogeneity_null, prior_heterogeneity, prior_bias_null, prior_bias, object$add_info[["prior_scale"]])
+    new_priors <- .check_and_list_priors(NULL, prior_effect_null, prior_effect, prior_heterogeneity_null, prior_heterogeneity, prior_bias_null, prior_bias, prior_rho_null, prior_rho, object$add_info[["prior_scale"]])
 
-    object$models[length(object$models) + 1]  <- list(.make_models(new_priors)[[1]])
+    object$models[length(object$models) + 1]  <- list(.make_models(new_priors, !attr(object$data, "all_independent"))[[1]])
 
     if(!is.null(prior_weights)){
       object$models[[length(object$models)]]$prior_weights     <- prior_weights
